package info.textgrid.lab.collatex.model;

import info.textgrid.lab.collatex.CollateXPlugin;
import info.textgrid.lab.core.model.CrudServiceException;
import info.textgrid.lab.core.model.TextGridObject;

import org.eclipse.core.runtime.IAdapterFactory;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.MultiStatus;
import org.eclipse.osgi.util.NLS;
import org.eclipse.ui.statushandlers.StatusManager;

/**
 * Converts {@link CollationSetWitness}es to {@link TextGridObject}s using
 * Eclipse's standard adapter mechanism. clients shouldn't call this class
 * directly but rather use the generic adapter mechanism
 */
@SuppressWarnings("rawtypes")	// cf. API
public class CollationSetAdapterFactory implements IAdapterFactory {

	private static final Class[] ADAPTER_LIST = new Class[] { TextGridObject.class };

	@SuppressWarnings("unchecked") // cf. API
	@Override
	public Object getAdapter(final Object adaptableObject, final Class adapterType) {
		if (adaptableObject instanceof CollationSetWitness) {
			final CollationSetWitness witness = (CollationSetWitness) adaptableObject;
			if (adapterType.isAssignableFrom(TextGridObject.class))
				try {
					return TextGridObject.getInstance(witness.getUri(), true);
				} catch (final CrudServiceException e) {
					StatusManager
					.getManager()
					.handle(new MultiStatus(
							CollateXPlugin.PLUGIN_ID,
							0,
							new IStatus[] { e.getStatus() },
							NLS.bind(
									Messages.CollationSetAdapterFactory_WitnessMetadataFailed,
									witness, e.getLocalizedMessage()),
									e)); // FIXME show this message?
				}
		}
		return null;
	}

	@Override
	public Class[] getAdapterList() {
		return ADAPTER_LIST ;
	}

}
